package com.chelvc.framework.common.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import javax.validation.Constraint;
import javax.validation.Payload;

import com.chelvc.framework.common.validator.EnumerationValidator;

/**
 * 自定义枚举参数校验注解
 *
 * @author Woody
 * @date 2025/5/20
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Constraint(validatedBy = EnumerationValidator.class)
@Target({ElementType.FIELD, ElementType.PARAMETER})
public @interface Enumerations {
    /**
     * 是否支持动态枚举
     *
     * @return true/false
     */
    boolean dynamic() default true;

    /**
     * 获取异常消息
     *
     * @return 异常消息
     */
    String message() default "Invalid enumeration";

    /**
     * 获取对象分组（固定写法）
     *
     * @return 对象数组
     */
    Class<?>[] groups() default {};

    /**
     * 获取载体对象（固定写法）
     *
     * @return 载体对象数组
     */
    Class<? extends Payload>[] payload() default {};
}
