package com.chelvc.framework.common.jackson;

import java.io.IOException;
import java.lang.reflect.Field;
import java.util.Map;

import com.chelvc.framework.common.model.Enumeration;
import com.chelvc.framework.common.util.ObjectUtils;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;

/**
 * JSON枚举序列化处理器
 *
 * @author Woody
 * @date 2024/1/30
 */
public class JacksonEnumerateSerializer extends StdSerializer<Object> {
    /**
     * 编号属性名称
     */
    public static final String CODE = "code";

    /**
     * 描述属性名称
     */
    public static final String DESCRIPTION = "description";

    public JacksonEnumerateSerializer() {
        super(Object.class);
    }

    @Override
    public void serialize(Object value, JsonGenerator generator, SerializerProvider provider) throws IOException {
        if (value instanceof Enum || value instanceof Enumeration) {
            generator.writeStartObject();
            Map<String, Field> fields = ObjectUtils.getClassFields(value.getClass());
            if (value instanceof Enum && !fields.containsKey(CODE)) {
                generator.writeStringField(CODE, ((Enum<?>) value).name());
            }
            fields.forEach((property, field) -> {
                if (!field.isAnnotationPresent(JsonIgnore.class)) {
                    try {
                        generator.writeObjectField(property, ObjectUtils.getObjectValue(value, field));
                    } catch (IOException e) {
                        throw new RuntimeException(e);
                    }
                }
            });
            if (value instanceof Enum && !fields.containsKey(DESCRIPTION)) {
                generator.writeStringField(DESCRIPTION, ((Enum<?>) value).name());
            }
            generator.writeEndObject();
        } else {
            generator.writeObject(value);
        }
    }
}
