package com.chelvc.framework.common.validator;

import java.util.Collection;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

import com.chelvc.framework.common.annotation.Enumerations;
import com.chelvc.framework.common.model.Enumeration;

/**
 * 自定义枚举参数验证器
 *
 * @author Woody
 * @date 2025/5/20
 */
public class EnumerationValidator implements ConstraintValidator<Enumerations, Object> {
    private Enumerations annotation;

    /**
     * 校验枚举参数
     *
     * @param value 参数值
     * @return true/false
     */
    private boolean validate(Object value) {
        return !(value instanceof Enumeration) || !((Enumeration) value).isDynamic();
    }

    @Override
    public void initialize(Enumerations annotation) {
        this.annotation = annotation;
    }

    @Override
    public boolean isValid(Object value, ConstraintValidatorContext context) {
        if (this.annotation == null || this.annotation.dynamic()) {
            return true;
        } else if (value instanceof Collection) {
            return ((Collection<?>) value).stream().allMatch(this::validate);
        }
        return this.validate(value);
    }
}
