package com.chelvc.framework.database.handler;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import com.chelvc.framework.common.model.Enumeration;
import lombok.NonNull;
import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;

/**
 * 自定义枚举类型处理实现
 *
 * @author Woody
 * @date 2025/5/22
 */
public class EnumerationTypeHandler extends BaseTypeHandler<Enumeration> {
    private final Class<? extends Enumeration> type;

    public EnumerationTypeHandler(@NonNull Class<? extends Enumeration> type) {
        this.type = type;
    }

    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, Enumeration parameter, JdbcType jdbcType)
            throws SQLException {
        ps.setString(i, parameter.getCode());
    }

    @Override
    public Enumeration getNullableResult(ResultSet rs, String columnName) throws SQLException {
        return Enumeration.parse(this.type, rs.getString(columnName));
    }

    @Override
    public Enumeration getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        return Enumeration.parse(this.type, rs.getString(columnIndex));
    }

    @Override
    public Enumeration getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        return Enumeration.parse(this.type, cs.getString(columnIndex));
    }
}
