package com.chelvc.framework.email;

import java.io.Serializable;
import javax.mail.Flags;
import javax.mail.search.AndTerm;
import javax.mail.search.ComparisonTerm;
import javax.mail.search.FlagTerm;
import javax.mail.search.FromStringTerm;
import javax.mail.search.SearchTerm;
import javax.mail.search.SentDateTerm;
import javax.mail.search.SubjectTerm;

import com.chelvc.framework.common.model.Period;
import com.chelvc.framework.common.util.StringUtils;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * 邮件筛选条件
 *
 * @author Woody
 * @date 2025/5/28
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
public class Search implements Serializable {
    /**
     * 发件人
     */
    private String from;

    /**
     * 是否已查看
     */
    private Boolean seen;

    /**
     * 时间周期
     */
    private Period period;

    /**
     * 邮件主题
     */
    private String subject;

    /**
     * 是否最近的
     */
    private Boolean recent;

    /**
     * 筛选条件且逻辑运算
     *
     * @param a 筛选条件
     * @param b 筛选条件
     * @return 筛选条件
     */
    public static SearchTerm and(SearchTerm a, SearchTerm b) {
        return a == null ? b : b == null ? a : new AndTerm(a, b);
    }

    /**
     * 将自定义筛选条件转换成邮件消息筛选条件
     *
     * @return 筛选条件实例
     */
    public SearchTerm term() {
        SearchTerm term = null;
        if (StringUtils.notEmpty(this.from)) {
            term = new FromStringTerm(this.from);
        }
        if (StringUtils.notEmpty(this.subject)) {
            term = and(term, new SubjectTerm(this.subject));
        }
        if (this.seen != null) {
            term = and(term, new FlagTerm(new Flags(Flags.Flag.SEEN), this.seen));
        }
        if (this.recent != null) {
            term = and(term, new FlagTerm(new Flags(Flags.Flag.RECENT), this.recent));
        }
        if (this.period != null) {
            if (this.period.getBegin() != null) {
                term = and(term, new SentDateTerm(ComparisonTerm.GE, this.period.getBegin()));
            }
            if (this.period.getEnd() != null) {
                term = and(term, new SentDateTerm(ComparisonTerm.LE, this.period.getEnd()));
            }
        }
        return term;
    }
}
