package com.chelvc.framework.group;

import java.util.Collection;
import java.util.Map;

import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Caps;

/**
 * 场景分组存储接口
 *
 * @author Woody
 * @date 2024/11/23
 */
public interface GroupStore {
    /**
     * 获取场景分组
     *
     * @param scene 场景标识
     * @return 分组标识
     */
    default Caps get(String scene) {
        return this.get(SessionContextHolder.getId(), scene);
    }

    /**
     * 获取场景分组
     *
     * @param id    用户ID
     * @param scene 场景标识
     * @return 分组标识
     */
    Caps get(Long id, String scene);

    /**
     * 批量获取场景分组
     *
     * @param scenes 分组标识集合
     * @return 场景/分组映射表
     */
    default Map<String, Caps> get(Collection<String> scenes) {
        return this.get(SessionContextHolder.getId(), scenes);
    }

    /**
     * 批量获取场景分组
     *
     * @param id     用户ID
     * @param scenes 分组标识集合
     * @return 场景/分组映射表
     */
    Map<String, Caps> get(Long id, Collection<String> scenes);

    /**
     * 设置场景分组，如果分组不存在则设置分组，否则忽略
     *
     * @param scene 场景标识
     * @param group 分组标识
     * @return 分组标识
     */
    Caps set(String scene, Caps group);

    /**
     * 批量设置场景分组，如果分组不存在则设置分组，否则忽略
     *
     * @param groups 分组/场景映射表
     * @return 分组/场景映射表
     */
    Map<String, Caps> set(Map<String, Caps> groups);
}
